
"""
Sets up input directory for BiG-SCAPE by creating symbolic links to .gbk files from the output directory generated by Antismash.
"""

import glob
import os
import subprocess
import argparse

def main():
    parser = argparse.ArgumentParser()

    parser.add_argument("--input_dir", type=str, required=True)
    parser.add_argument("--output_dir", type=str, required=True)
    parser.add_argument("--prefix", type=str, required=True)

    args = parser.parse_args()

    input_dir = args.input_dir
    output_dir = args.output_dir
    prefix = args.prefix
    
    # create output directory
    subprocess.run(["mkdir", "-p", output_dir])

    input_dir_files = glob.glob(input_dir + '/*region*.gbk')

    for file in input_dir_files:
        # get the base name
        file_basename = os.path.basename(file)
        # append prefix to above base name
        file_basename = prefix + '.' + file_basename
        
        output_file = output_dir + "/" + file_basename

        # create symbolic link
        subprocess.run(["ln", "-s", os.path.relpath(file, os.path.dirname(output_file)), output_file])

if __name__ == '__main__':
    main()